PodcastRemoteItem

Struct PodcastRemoteItem 

pub struct PodcastRemoteItem {
    pub feed_guid: Option<String>,
    pub feed_url: Option<Url>,
    pub item_guid: Option<String>,
    pub medium: Option<String>,
    pub title: Option<String>,
}
Podcast 2.0 remote item reference

A reference to a remote podcast feed or episode, used within podcast:podroll.

Fields

feed_guid: Option<String>

Feed GUID (feedGuid attribute)

feed_url: Option<Url>

Feed URL (feedUrl attribute)

Security Warning

This URL comes from untrusted feed input and has NOT been validated for SSRF.

item_guid: Option<String>

Item GUID (itemGuid attribute)

medium: Option<String>

Content medium type (medium attribute)

title: Option<String>

Display title (title attribute)