pub struct TextInput {
pub title: Option<String>,
pub description: Option<String>,
pub name: Option<String>,
pub link: Option<String>,
}Expand description
RSS 2.0 <textInput> element — text input form associated with the channel
Fields
title: Option<String>Title of the Submit button in the text input area
description: Option<String>Explains the text input area
name: Option<String>The name of the text object in the text input area
link: Option<String>The URL of the CGI script that processes text input requests